"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
const path_1 = require("path");
const fs_1 = require("fs");
const meow_1 = __importDefault(require("meow"));
const meow_helper_1 = __importStar(require("meow-helper"));
const command = "pgen";
const pkg = JSON.parse(fs_1.readFileSync(path_1.join(__dirname, "../../package.json"), { encoding: "utf8" }));
const args = { "GENERATOR*": "The name or the path of the generator." };
const flags = {
    // Generator Options
    clear: { type: "boolean", desc: "Whether to clear the destination directory before creating files." },
    outDir: { alias: "o", type: "string", desc: "Path of the output directory." },
    contextFile: { type: "string", desc: "Path to a JSON or JS file providing extra context for templates." },
    log: { type: "boolean", default: true, desc: "Whether to log output to console." },
    ...meow_helper_1.commonFlags,
    // pg-structure options
    commentDataToken: { type: "string", desc: "Tag name to extract JSON data from from database object's comments." },
    envPrefix: { type: "string", default: "DB", desc: "Environment variable prefix to get database client details." },
    excludeSchemas: {
        alias: "e",
        isMultiple: true,
        type: "string",
        desc: "Schema or a pattern similar to SQL's LIKE to select excluded schemas. See examples below.",
    },
    foreignKeyAliasSeparator: { type: "string", desc: "Character to separate source alias" },
    foreignKeyAliasTargetFirst: {
        type: "boolean",
        desc: "Whether first part of the foreign key aliases contains target alias (i.e company_employees) or source alias (e.g. employee_company).",
    },
    includeSchemas: {
        alias: "i",
        isMultiple: true,
        type: "string",
        desc: "Schema or a pattern similar to SQL's LIKE to select included schemas. See examples below.",
    },
    includeSystemSchemas: { type: "boolean", desc: "Whether to include PostgreSQL system schemas (e.g. pg_catalog) from database." },
    relationNameFunctions: {
        type: "string",
        desc: "Optional module that exports functions to generate names for relations. 'pg-generator' also provides builtin modules 'short', 'optimal' & 'descriptive'",
    },
    // Client options
    user: { type: "string", desc: "Database username. Default from environment var: PGUSER || USER || DB_USER" },
    password: { type: "string", desc: "Database password. Default from environment var: PGPASSWORD || DB_PASSWORD" },
    host: { type: "string", desc: "Database host. Default from environment var: PGHOST || DB_HOST" },
    database: { type: "string", desc: "Database to connect. Default from environment var: PGDATABASE || DB_DATABASE" },
    port: { type: "string", desc: "Database port. Default from environment var: PGPORT || DB_PORT" },
    connectionString: { type: "string", desc: "Connection string for database e.g. postgres://user:password@host:5432/database" },
    ssl: { type: "string", desc: "Passed directly to node.TLSSocket, supports all tls.connect options." },
};
const groups = {
    clear: {
        title: "General Options",
    },
    commentDataToken: {
        title: "'pg-structure' Options",
        description: "Options send to 'pg-structure'. Please see pg-structure.com for details.",
    },
    user: {
        title: "Client Options",
        description: "Options related to database connection. 'pg-generator' supports environment variables and '.env' files. Prefer to use environment variable to protect sensitive data.",
    },
};
const examples = [
    "npm install -g pg-generator-example",
    "",
    "pgen example --outDir models",
    "pgen example:md --outDir models",
    "pgen example --outDir models --contextFile './context.js'",
    "pgen example --outDir models --relationNameFunctions './custom-naming.js'",
    "",
    meow_helper_1.chalk.dim("Including & Excluding Schemas"),
    "pgen example -i user%",
    "pgen example -i user_meta -i user_main",
    "pgen example -e private%",
    "pgen example -e private_meta -e private_main",
    "",
    meow_helper_1.chalk.dim("Providing Connection Details"),
    "pgen example --outDir models --user user --password password --database database",
];
function getCLI() {
    const help = meow_helper_1.default({ lineLength: 140, flags, args, pkg, groups, examples, command });
    return meow_1.default(help, { flags, pkg, allowUnknownFlags: false });
}
exports.default = getCLI;
//# sourceMappingURL=meow-pgen.js.map