#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
const path_1 = require("path");
const os_1 = require("os");
const meow_helper_1 = require("meow-helper");
const fs_1 = require("fs");
const ignor_1 = require("ignor");
const meow_pgen_scaffold_1 = __importDefault(require("./meow-pgen-scaffold"));
const utils_1 = require("../utils");
const SCAFFOLD_DIR = path_1.join(__dirname, "../../module-files/scaffolds");
function showError(message, code = 1) {
    console.log(meow_helper_1.chalk.red(`${message}${os_1.EOL}`));
    process.exit(code);
}
function getScaffoldsMessage(scaffolds) {
    const available = scaffolds.join(`${os_1.EOL}  ● `);
    return available ? `Available scaffolds are:${os_1.EOL}  ● ${available}` : "";
}
async function logHelp(cli, scaffolds) {
    console.log(cli.help);
    console.log(getScaffoldsMessage(scaffolds), os_1.EOL);
}
async function renameProject(path, name) {
    const pkgPath = path_1.join(path, "package.json");
    const pkg = JSON.parse(await fs_1.promises.readFile(pkgPath, { encoding: "utf-8" }));
    pkg.name = name;
    await fs_1.promises.writeFile(pkgPath, JSON.stringify(pkg, undefined, 2));
}
async function executeCommand() {
    var _a;
    const cli = meow_pgen_scaffold_1.default();
    const scaffolds = (await fs_1.promises.readdir(SCAFFOLD_DIR, { withFileTypes: true })).filter((e) => e.isDirectory()).map((e) => e.name);
    const scaffold = cli.input[0];
    const outDir = cli.flags.outDir;
    const name = (_a = cli.flags.name) !== null && _a !== void 0 ? _a : `pg-generator-${path_1.basename(outDir, path_1.extname(outDir)).replace("pg-generator-", "")}`;
    if (cli.flags.help)
        return logHelp(cli, scaffolds);
    if (scaffold === undefined)
        showError("SCAFFOLD is required.");
    if (!scaffolds.includes(scaffold))
        showError(`Unknown scaffold "${scaffold}". ${getScaffoldsMessage(scaffolds)}`);
    try {
        const destinationEntries = await fs_1.promises.readdir(outDir).catch(ignor_1.ignoreCode("ENOENT"));
        if (destinationEntries && destinationEntries.length > 0)
            showError(`Output directory "${outDir}" is not empty.`);
    }
    catch (error) {
        if (error.code === "ENOTDIR")
            showError(`"${outDir}" is not a directory.`);
    }
    try {
        await utils_1.copyDir(path_1.join(SCAFFOLD_DIR, scaffold), outDir);
        await renameProject(outDir, name);
        console.log(meow_helper_1.chalk.green(`"${name}" is created in "${outDir}" using "${scaffold}" scaffold.`));
    }
    catch (error) {
        if ((error === null || error === void 0 ? void 0 : error.type) !== "PgenError")
            throw error;
    }
    return undefined;
}
executeCommand().catch(console.log);
//# sourceMappingURL=pgen-scaffold%20copy.js.map