#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
const os_1 = require("os");
const meow_helper_1 = require("meow-helper");
const meow_pgen_scaffold_1 = __importDefault(require("./meow-pgen-scaffold"));
const scaffold_1 = require("../scaffold");
function showError(message, code = 1) {
    console.log(meow_helper_1.chalk.red(`${message}${os_1.EOL}`));
    process.exit(code);
}
async function logHelp(cli, scaffolds) {
    console.log(cli.help);
    console.log(scaffold_1.getScaffoldsMessage(scaffolds), os_1.EOL);
}
async function executeCommand() {
    const cli = meow_pgen_scaffold_1.default();
    const scaffolds = await scaffold_1.readScaffolds();
    if (cli.flags.help)
        return logHelp(cli, scaffolds);
    const scaffoldName = cli.input[0];
    try {
        await scaffold_1.scaffold(scaffoldName, cli.flags);
        console.log(meow_helper_1.chalk.green(`"${scaffoldName}" is created in "${cli.flags.outDir}" using "${scaffoldName}" scaffold.`));
    }
    catch (error) {
        if (error.type !== "PgenError")
            throw error;
        showError(error.message);
    }
    return undefined;
}
executeCommand().catch(console.log);
//# sourceMappingURL=pgen-scaffold.js.map