#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
const os_1 = require("os");
const meow_helper_1 = require("meow-helper");
const meow_pgen_1 = __importDefault(require("./meow-pgen"));
const generate_1 = require("../generate");
const utils_1 = require("../utils");
function showError(message, code = 1) {
    console.log(meow_helper_1.chalk.red(`${message}${os_1.EOL}`));
    process.exit(code);
}
function getSubGeneratorsMessage(generator, subGenerators) {
    const available = subGenerators === null || subGenerators === void 0 ? void 0 : subGenerators.map((name) => `${generator}:${name}`).join(`${os_1.EOL}  ● `);
    return available ? ` Available sub-generators of "${generator}" are:${os_1.EOL}  ● ${available}` : "";
}
async function logHelp(cli, generator) {
    // const subGenerators = (await readGenerators(generator))?.generators;
    const subGenerators = await utils_1.readGenerators(generator);
    console.log(cli.help);
    console.log(getSubGeneratorsMessage(generator, subGenerators), os_1.EOL);
}
async function executeCommand() {
    const cli = meow_pgen_1.default();
    if (cli.input[0] === undefined)
        showError("GENERATOR is required.");
    const [generator, subGenerator] = cli.input[0].split(":");
    if (cli.flags.help)
        return logHelp(cli, generator);
    try {
        return await generate_1.generate(generator, subGenerator, cli.flags);
    }
    catch (error) {
        if ((error === null || error === void 0 ? void 0 : error.type) !== "PgenError")
            throw error;
        return showError(`${error.message}${getSubGeneratorsMessage(generator, error === null || error === void 0 ? void 0 : error.subGenerators)}`);
    }
}
executeCommand().catch(console.log);
//# sourceMappingURL=pgen.js.map