import { Db, DbObject } from "pg-structure";
import { Context } from "../types/index";
/**
 * Adds extra data to context. More spesific data overrides generic one:
 *
 * - Adds global data. (Key: `global`).
 * - Adds related data of the database object. (e.g. `tables."public.member"`, `schemas.public` etc.)
 *
 * @param dbObject is the context data.
 * @param extra is the extra context data.
 * @returns combined data.
 *
 * @example
 * const extraContext = {
 *   "global": { a: 1 },
 *   "tables": { "public.member": { skip: true } }
 * };
 * augmentContext(dbObject, extraContext); // { table: { name: "member", columns: [...] }, a:1, skip: true }
 */
export declare function augmentContext(dbObject: Db | DbObject, extra: Record<string, any>): Context;
//# sourceMappingURL=augment-context.d.ts.map