"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.augmentContext = void 0;
/* eslint-disable import/export */
const pg_structure_1 = require("pg-structure");
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const filter_functions_1 = require("./filter-functions");
/**
 * Adds extra data to context. More spesific data overrides generic one:
 *
 * - Adds global data. (Key: `global`).
 * - Adds related data of the database object. (e.g. `tables."public.member"`, `schemas.public` etc.)
 *
 * @param dbObject is the context data.
 * @param extra is the extra context data.
 * @returns combined data.
 *
 * @example
 * const extraContext = {
 *   "global": { a: 1 },
 *   "tables": { "public.member": { skip: true } }
 * };
 * augmentContext(dbObject, extraContext); // { table: { name: "member", columns: [...] }, a:1, skip: true }
 */
function augmentContext(dbObject, extra) {
    var _a;
    const type = filter_functions_1.plural(filter_functions_1.camelCase(dbObject.constructor.name)); // e.g. tables
    const name = dbObject instanceof pg_structure_1.Db ? dbObject.name : dbObject.fullName;
    const instanceVariable = filter_functions_1.camelCase(dbObject.constructor.name); // "db", "table", "materializedView"
    // Don't mutate original data within merge. Otherwise if same data file (as module) is used in same application, it will receive mutated data.
    return { o: dbObject, [instanceVariable]: dbObject, ...lodash_merge_1.default({}, extra.global, (_a = extra[type]) === null || _a === void 0 ? void 0 : _a[name]) };
}
exports.augmentContext = augmentContext;
//# sourceMappingURL=augment-context.js.map