"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDbObjects = void 0;
const pgen_error_1 = require("./pgen-error");
const isSchemaAttribute = (db, accessor) => Array.isArray(db.schemas[0][accessor]);
const isDbAttribute = (db, accessor) => Array.isArray(db[accessor]);
/**
 * Gets all database objects from all schemas to be used as context for the given className and accessor.
 *
 * @param db is the `pg-structure` `Db` instance.
 * @param className is the pg-structure class name to return instances of.
 * @param accessor is the pg-structure accessor name to access database objects collection.
 * @param templatePath is the template path to get database objects for.
 *
 * @example
 * getDbObjects(db, "table", "tables", "x/y/[table]{name}.js.njk"); // Table[];
 */
function getDbObjects(db, className, accessor, templatePath) {
    if (className === "Db")
        return [db];
    if (isSchemaAttribute(db, accessor))
        return db.schemas.flatMap((schema) => schema[accessor]);
    if (isDbAttribute(db, accessor))
        return db[accessor];
    throw new pgen_error_1.PgenError(`'${className}' is not a known database object type: ${templatePath}`);
}
exports.getDbObjects = getDbObjects;
//# sourceMappingURL=get-db-objects.js.map