"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDb = void 0;
const pg_structure_1 = __importDefault(require("pg-structure"));
/**
 * Gets `node-postgres` client, client config or connection string based on the options. If none of them
 * is possible with given options, returns `undefined`.
 *
 * @param options are the options.
 * @returns `node-postgres` client, client config or connection string.
 */
function getClient(options) {
    if (options.client)
        return options.client;
    const keys = ["user", "password", "host", "database", "password", "host", "database", "port", "connectionString", "ssl"];
    const config = {};
    keys.filter((key) => options[key] !== undefined).forEach((key) => (config[key] = options[key])); // eslint-disable-line no-return-assign
    return Object.keys(config).length > 0 ? config : undefined;
}
async function getDb(options) {
    const client = getClient(options);
    const db = await pg_structure_1.default(client, options);
    return db;
}
exports.getDb = getDb;
//# sourceMappingURL=get-db.js.map