"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseTemplatePath = void 0;
const path_1 = require("path");
const pgen_error_1 = require("./pgen-error");
const filter_functions_1 = require("./filter-functions");
/**
 * Parses given template path and returns pg-structure class name, accessor name to get collection of instances
 * and target path for the given template path. Allows an optional single space after type.
 *
 * @param templatePath is the template path to get the class name and the accessor.
 * @throws if template path does not contain a class type.
 *
 * @example
 * getClassName("x/y/[table]{name}.js.njk"); // { className: "Table", accessor: "tables", targetPath: "x/y/{name}.js.njk" };
 * getClassName("x/y/[table] {name}.js.njk"); // { className: "Table", accessor: "tables", targetPath: "x/y/{name}.js.njk"  };
 */
function parseTemplatePath(templatePath) {
    // Capture characters between "[]" at the beginning and rest of the string. x/y/[table]{name}.js.njk -> ["[table]", "table", "{name}.js.njk"]
    const found = path_1.basename(templatePath).match(/^\[([-\w]+?)\] ?(.+)$/);
    /* istanbul ignore if */
    if (!found)
        throw new pgen_error_1.PgenError("Template error. Template path does not contain a type.");
    return { className: filter_functions_1.classCase(found[1]), accessor: filter_functions_1.plural(filter_functions_1.camelCase(found[1])), targetPath: path_1.join(path_1.dirname(templatePath), found[2]) };
}
exports.parseTemplatePath = parseTemplatePath;
//# sourceMappingURL=parse-template-path.js.map