"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PgenError = void 0;
/* eslint-disable @typescript-eslint/explicit-function-return-type */
const os_1 = require("os");
const util_1 = require("util");
const messages = {
    NOGEN: (n) => `You don't seem to have a generator with the name '${n}' installed.`,
    NOSUB: (n, s) => `'${n}' doesn't seem to have a sub-generator with the name '${s}'.`,
    // NOTAGEN: (n = "", s = "") => `'${n}' exports '${s}' but it is not a sub-generator.`,
    // NOEXP: (n = "") => `${n} exists, but does not have any sub-generators.`,
};
class PgenError extends Error {
    constructor() {
        super(...arguments);
        this.code = "GENERAL";
        this.type = "PgenError";
    }
    static withCode(code, message) {
        const error = new PgenError(message);
        error.code = code;
        return error;
    }
    static collisionError(reportObject) {
        const report = util_1.inspect(reportObject, { depth: null });
        const message = `Some relations have same names. Use "optimal" or "descriptive" for "relationNameFunctions" option or proivde your own naming functions.${os_1.EOL}${report}`;
        const error = this.withCode("RELCOL", message);
        return error;
    }
    static composerError(code, id, subGenerator, subGenerators) {
        const message = messages[code](id, subGenerator === "" || subGenerator === undefined ? "index.js or app" : subGenerator);
        const error = this.withCode(code, message);
        error.subGenerators = subGenerators;
        return error;
    }
}
exports.PgenError = PgenError;
//# sourceMappingURL=pgen-error.js.map