"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanTemplateDir = void 0;
const path_1 = require("path");
const fdir_1 = require("fdir");
const junk_1 = __importDefault(require("junk"));
/**
 * Scans the template directory recursively and gets all template file paths.
 *
 * @param templateRoot is the root directory of the templates.
 * @returns all template files and files to copy.
 */
async function scanTemplateDir(templateRoot) {
    const filePaths = { templates: [], files: [] };
    // Scan template root and filter partials and junk files such as `.DS_Store` and `Thumbs.db`
    const pathsWithBase = (await new fdir_1.fdir()
        .filter((path) => junk_1.default.not(path_1.basename(path)) && path_1.basename(path_1.dirname(path)) !== "partials")
        .withBasePath()
        .crawl(templateRoot)
        .withPromise());
    // Group template files and non-template files and convert to relative files.
    pathsWithBase.forEach((path) => {
        const type = path_1.basename(path).match(/^\[([-\w]+?)\]/) ? "templates" : "files";
        filePaths[type].push(path_1.relative(templateRoot, path));
    });
    return filePaths;
}
exports.scanTemplateDir = scanTemplateDir;
//# sourceMappingURL=scan-template-dir.js.map